==> mule-tests-allure-4.3.0-20220919-sources.jar: com/mulesoft/test/allure/AllureConstants.java <==
/*
 * (c) 2003-2020 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.test.allure;

public interface AllureConstants {

  interface CompatibilityFeature {

    String COMPATIBILITY = "Compatibility";

    interface Stories {

      String IntegrationStory = "Integration between compatibility components and the core components";

      String JMS_TRANSPORT = "JMS Transport";

      String HTTP_TRANSPORT = "HTTP Transport";

      String CXF_MODULE = "CXF Module";

      String VM_TRANSPORT = "VM Transport";

      String TCP_TRANSPORT = "TCP Transport";

      String SSL_TRANSPORT = "SSL Transport";

      String SPRING_EXTRAS = "Spring Extras";
    }

  }

  interface MozartFeature {

    String MOZART_USE_CASE = "Mozart Use Cases";

  }

  interface FtpsFeature {

    String FTPS_EXTENSION = "FTPS Extension";

    interface FtpsStory {

    }
  }

  interface ClusteringFeature {

    String CLUSTERING = "Clustering";

  }

  interface BatchFeature {

    String BATCH = "Batch module";
  }

  interface CacheFeature {

    String CACHE = "Cache scope";

  }

  interface ErrorHandlingFeature {

    String ERROR_HANDLING = "Error Handling";
  }

  interface KryoSerializerFeature {

    String KRYO = "Kryo serialization";

  }

}

==> mule-tests-allure-4.4.0-20220919-sources.jar: com/mulesoft/test/allure/AllureConstants.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.test.allure;

public interface AllureConstants {

  interface EeComponentsFeature {

    String CORE_EE_COMPONENTS = "Core EE Components";

    interface TransformStory {

      String TRANSFORM = "Transform";

    }

    interface DynamicEvaluateStory {

      String DYNAMIC_EVALUATE = "Dynamic Evaluate";

    }

  }

  interface CompatibilityFeature {

    String COMPATIBILITY = "Compatibility";

    interface Stories {

      String IntegrationStory = "Integration between compatibility components and the core components";

      String JMS_TRANSPORT = "JMS Transport";

      String HTTP_TRANSPORT = "HTTP Transport";

      String CXF_MODULE = "CXF Module";

      String VM_TRANSPORT = "VM Transport";

      String TCP_TRANSPORT = "TCP Transport";

      String SSL_TRANSPORT = "SSL Transport";

      String SPRING_EXTRAS = "Spring Extras";
    }

  }

  interface MozartFeature {

    String MOZART_USE_CASE = "Mozart Use Cases";

  }

  interface FtpsFeature {

    String FTPS_EXTENSION = "FTPS Extension";

    interface FtpsStory {

    }
  }

  interface ClusteringFeature {

    String CLUSTERING = "Clustering";

  }

  interface BatchFeature {

    String BATCH = "Batch module";
  }

  interface CacheFeature {

    String CACHE = "Cache scope";

  }

  interface KryoSerializerFeature {

    String KRYO = "Kryo serialization";

  }

  interface Profiling {

    String PROFILING_EE = "Profiling";


    interface ProfilingServiceStory {

      String SERVER_PLUGIN = "Profiling Server Plugin";
    }
  }

}
